@@ -1,14 +1,17 @@
+# -*- coding: utf-8 -*-
 """
 Progress bar
 ------------
 """
-from __future__ import print_function, division
+from __future__ import division, print_function
+
+import datetime
+import sys
 import warnings
 from abc import abstractmethod
-import datetime
-from plumbum.lib import six
+
 from plumbum.cli.termsize import get_terminal_size
-import sys
+from plumbum.lib import six
 
 
 class ProgressBase(six.ABC):
@@ -22,13 +25,15 @@ class ProgressBase(six.ABC):
     :param clear: Clear the progress bar afterwards, if applicable.
     """
 
-    def __init__(self,
-                 iterator=None,
-                 length=None,
-                 timer=True,
-                 body=False,
-                 has_output=False,
-                 clear=True):
+    def __init__(
+        self,
+        iterator=None,
+        length=None,
+        timer=True,
+        body=False,
+        has_output=False,
+        clear=True,
+    ):
         if length is None:
             length = len(iterator)
         elif iterator is None:
@@ -93,8 +98,11 @@ class ProgressBase(six.ABC):
         if self.value < 1:
             return None, None
         elapsed_time = datetime.datetime.now() - self._start_time
-        time_each = (elapsed_time.days * 24 * 60 * 60 + elapsed_time.seconds +
-                     elapsed_time.microseconds / 1000000.0) / self.value
+        time_each = (
+            elapsed_time.days * 24 * 60 * 60
+            + elapsed_time.seconds
+            + elapsed_time.microseconds / 1000000.0
+        ) / self.value
         time_remaining = time_each * (self.length - self.value)
         return elapsed_time, datetime.timedelta(0, time_remaining, 0)
 
@@ -103,11 +111,10 @@ class ProgressBase(six.ABC):
         if self.value < 1:
             return "Starting...                         "
         else:
-            elapsed_time, time_remaining = list(
-                map(str, self.time_remaining()))
-            return "{0} completed, {1} remaining".format(
-                elapsed_time.split('.')[0],
-                time_remaining.split('.')[0])
+            elapsed_time, time_remaining = list(map(str, self.time_remaining()))
+            return "{} completed, {} remaining".format(
+                elapsed_time.split(".")[0], time_remaining.split(".")[0]
+            )
 
     @abstractmethod
     def done(self):
@@ -134,7 +141,7 @@ class Progress(ProgressBase):
         self.value = self.length
         self.display()
         if self.clear and not self.has_output:
-            print("\r", len(str(self)) * " ", "\r", end='', sep='')
+            print("\r", len(str(self)) * " ", "\r", end="", sep="")
         else:
             print()
 
@@ -145,36 +152,38 @@ class Progress(ProgressBase):
             return "0/0 complete"
 
         percent = max(self.value, 0) / self.length
-        ending = ' ' + (self.str_time_remaining()
-                        if self.timer else '{0} of {1} complete'.format(
-                            self.value, self.length))
+        ending = " " + (
+            self.str_time_remaining()
+            if self.timer
+            else "{} of {} complete".format(self.value, self.length)
+        )
         if width - len(ending) < 10 or self.has_output:
             self.width = 0
             if self.timer:
-                return "{0:.0%} complete: {1}".format(
-                    percent, self.str_time_remaining())
+                return "{:.0%} complete: {}".format(percent, self.str_time_remaining())
             else:
-                return "{0:.0%} complete".format(percent)
+                return "{:.0%} complete".format(percent)
 
         else:
             self.width = width - len(ending) - 2 - 1
             nstars = int(percent * self.width)
-            pbar = '[' + '*' * nstars + ' ' * (
-                self.width - nstars) + ']' + ending
+            pbar = "[" + "*" * nstars + " " * (self.width - nstars) + "]" + ending
 
-        str_percent = ' {0:.0%} '.format(percent)
+        str_percent = " {:.0%} ".format(percent)
 
-        return pbar[:self.width // 2 -
-                    2] + str_percent + pbar[self.width // 2 +
-                                            len(str_percent) - 2:]
+        return (
+            pbar[: self.width // 2 - 2]
+            + str_percent
+            + pbar[self.width // 2 + len(str_percent) - 2 :]
+        )
 
     def display(self):
         disptxt = str(self)
         if self.width == 0 or self.has_output:
             print(disptxt)
         else:
-            print("\r", end='')
-            print(disptxt, end='')
+            print("\r", end="")
+            print(disptxt, end="")
             sys.stdout.flush()
 
 
@@ -187,9 +196,9 @@ class ProgressIPy(ProgressBase):  # pragma: no cover
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
             try:
-                from ipywidgets import IntProgress, HTML, HBox  # type: ignore
+                from ipywidgets import HTML, HBox, IntProgress
             except ImportError:  # Support IPython < 4.0
-                from IPython.html.widgets import IntProgress, HTML, HBox  # type: ignore
+                from IPython.html.widgets import HTML, HBox, IntProgress
 
         super(ProgressIPy, self).__init__(*args, **kargs)
         self.prog = IntProgress(max=self.length)
@@ -197,7 +206,8 @@ class ProgressIPy(ProgressBase):  # pragma: no cover
         self._box = HBox((self.prog, self._label))
 
     def start(self):
-        from IPython.display import display  # type: ignore
+        from IPython.display import display
+
         display(self._box)
         super(ProgressIPy, self).start()
 
@@ -210,7 +220,7 @@ class ProgressIPy(ProgressBase):  # pragma: no cover
     def value(self, val):
         self._value = val
         self.prog.value = max(val, 0)
-        self.prog.description = "{0:.2%}".format(self.value / self.length)
+        self.prog.description = "{:.2%}".format(self.value / self.length)
         if self.timer and val > 0:
             self._label.value = self.HTMLBOX.format(self.str_time_remaining())
 
@@ -238,9 +248,9 @@ class ProgressAuto(ProgressBase):
         try:  # pragma: no cover
             __IPYTHON__
             try:
-                from traitlets import TraitError  # type: ignore
+                from traitlets import TraitError
             except ImportError:  # Support for IPython < 4.0
-                from IPython.utils.traitlets import TraitError  # type: ignore
+                from IPython.utils.traitlets import TraitError
 
             try:
                 return ProgressIPy(*args, **kargs)
@@ -256,10 +266,11 @@ ProgressAuto.register(Progress)
 
 def main():
     import time
+
     tst = Progress.range(20)
     for i in tst:
         time.sleep(1)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
