@@ -1,14 +1,32 @@
+# -*- coding: utf-8 -*-
 """
 Terminal-related utilities
 --------------------------
 """
 
-from __future__ import division, print_function, absolute_import
-import sys
+from __future__ import absolute_import, division, print_function
+
 import os
+import sys
+
 from plumbum import local
-from .termsize import get_terminal_size
+
 from .progress import Progress
+from .termsize import get_terminal_size
+
+__all__ = (
+    "readline",
+    "ask",
+    "choose",
+    "prompt",
+    "get_terminal_size",
+    "Progress",
+    "get_terminal_size",
+)
+
+
+def __dir__():
+    return __all__
 
 
 def readline(message=""):
@@ -90,9 +108,9 @@ def choose(question, options, default=None):
         sys.stdout.write("(%d) %s\n" % (i, text))
     if default is not None:
         if defindex is None:
-            msg = "Choice [%s]: " % (default, )
+            msg = "Choice [{}]: ".format(default)
         else:
-            msg = "Choice [%d]: " % (defindex, )
+            msg = "Choice [%d]: " % (defindex,)
     else:
         msg = "Choice: "
     while True:
@@ -112,10 +130,7 @@ def choose(question, options, default=None):
         return choices[choice]
 
 
-def prompt(question,
-           type=str,
-           default=NotImplemented,
-           validator=lambda val: True):
+def prompt(question, type=str, default=NotImplemented, validator=lambda val: True):
     """
     Presents the user with a validated question, keeps asking if validation does not pass.
 
@@ -128,7 +143,7 @@ def prompt(question,
     """
     question = question.rstrip(" \t:")
     if default is not NotImplemented:
-        question += " [%s]" % (default, )
+        question += " [{}]".format(default)
     question += ": "
     while True:
         try:
@@ -137,23 +152,22 @@ def prompt(question,
             ans = ""
         if not ans:
             if default is not NotImplemented:
-                #sys.stdout.write("\b%s\n" % (default,))
+                # sys.stdout.write("\b%s\n" % (default,))
                 return default
             else:
                 continue
         try:
             ans = type(ans)
         except (TypeError, ValueError) as ex:
-            sys.stdout.write("Invalid value (%s), please try again\n" % (ex, ))
+            sys.stdout.write("Invalid value ({}), please try again\n".format(ex))
             continue
         try:
             valid = validator(ans)
         except ValueError as ex:
-            sys.stdout.write("%s, please try again\n" % (ex, ))
+            sys.stdout.write("{}, please try again\n".format(ex))
             continue
         if not valid:
-            sys.stdout.write(
-                "Value not in specified range, please try again\n")
+            sys.stdout.write("Value not in specified range, please try again\n")
             continue
         return ans
 
@@ -170,16 +184,17 @@ def hexdump(data_or_stream, bytes_per_line=16, aggregate=True):
                 if not buf:
                     break
                 yield buf
+
     else:
 
         def read_chunk():
             for i in range(0, len(data_or_stream), bytes_per_line):
-                yield data_or_stream[i:i + bytes_per_line]
+                yield data_or_stream[i : i + bytes_per_line]
 
     prev = None
     skipped = False
     for i, chunk in enumerate(read_chunk()):
-        hexd = " ".join("%02x" % (ord(ch), ) for ch in chunk)
+        hexd = " ".join("{:02x}".format(ord(ch)) for ch in chunk)
         text = "".join(ch if 32 <= ord(ch) < 127 else "." for ch in chunk)
         if aggregate and prev == chunk:
             skipped = True
@@ -187,8 +202,11 @@ def hexdump(data_or_stream, bytes_per_line=16, aggregate=True):
         prev = chunk
         if skipped:
             yield "*"
-        yield "%06x | %s| %s" % (i * bytes_per_line,
-                                 hexd.ljust(bytes_per_line * 3, " "), text)
+        yield "{:06x} | {}| {}".format(
+            i * bytes_per_line,
+            hexd.ljust(bytes_per_line * 3, " "),
+            text,
+        )
         skipped = False
 
 
@@ -206,7 +224,7 @@ def pager(rows, pagercmd=None):  # pragma: no cover
     pg = pagercmd.popen(stdout=None, stderr=None)
     try:
         for row in rows:
-            line = "%s\n" % (row, )
+            line = "{}\n".format(row)
             try:
                 pg.stdin.write(line)
                 pg.stdin.flush()
