@@ -1,26 +1,28 @@
+# -*- coding: utf-8 -*-
+import functools
 import shlex
 import subprocess
 import sys
-import functools
 from contextlib import contextmanager
-from plumbum.commands.processes import run_proc, iter_lines
-import plumbum.commands.modifiers
-from plumbum.lib import six
-from tempfile import TemporaryFile
 from subprocess import PIPE, Popen
+from tempfile import TemporaryFile
 from types import MethodType
 
+import plumbum.commands.modifiers
+from plumbum.commands.processes import iter_lines, run_proc
+from plumbum.lib import six
+
 
 class RedirectionError(Exception):
     """Raised when an attempt is made to redirect an process' standard handle,
     which was already redirected to/from a file"""
 
 
-#===================================================================================================
+# ===================================================================================================
 # Utilities
-#===================================================================================================
+# ===================================================================================================
 # modified from the stdlib pipes module for windows
-_safechars = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@%_-+=:,./'
+_safechars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@%_-+=:,./"
 _funnychars = '"`$\\'
 
 
@@ -31,6 +33,7 @@ def shquote(text):
         return shlex.quote(text)
     else:
         import pipes
+
         return pipes.quote(text)
 
 
@@ -38,9 +41,9 @@ def shquote_list(seq):
     return [shquote(item) for item in seq]
 
 
-#===================================================================================================
+# ===================================================================================================
 # Commands
-#===================================================================================================
+# ===================================================================================================
 class BaseCommand(object):
     """Base of all command objects"""
 
@@ -98,11 +101,20 @@ class BaseCommand(object):
     def _get_encoding(self):
         raise NotImplementedError()
 
-    def with_env(self, **envvars):
+    def with_env(self, **env):
         """Returns a BoundEnvCommand with the given environment variables"""
-        if not envvars:
+        if not env:
             return self
-        return BoundEnvCommand(self, envvars)
+        return BoundEnvCommand(self, env=env)
+
+    def with_cwd(self, path):
+        """
+        Returns a BoundEnvCommand with the specified working directory.
+        This overrides a cwd specified in a wrapping `machine.cwd()` context manager.
+        """
+        if not path:
+            return self
+        return BoundEnvCommand(self, cwd=path)
 
     setenv = with_env
 
@@ -142,11 +154,7 @@ class BaseCommand(object):
         """
         raise NotImplementedError()
 
-    def nohup(self,
-              cwd='.',
-              stdout='nohup.out',
-              stderr=None,
-              append=True):
+    def nohup(self, cwd=".", stdout="nohup.out", stderr=None, append=True):
         """Runs a command detached."""
         return self.machine.daemonic_popen(self, cwd, stdout, stderr, append)
 
@@ -292,7 +300,7 @@ class BoundCommand(BaseCommand):
         self.args = list(args)
 
     def __repr__(self):
-        return "BoundCommand(%r, %r)" % (self.cmd, self.args)
+        return "BoundCommand({!r}, {!r})".format(self.cmd, self.args)
 
     def _get_encoding(self):
         return self.cmd._get_encoding()
@@ -313,14 +321,15 @@ class BoundCommand(BaseCommand):
 
 
 class BoundEnvCommand(BaseCommand):
-    __slots__ = ("cmd", "envvars")
+    __slots__ = ("cmd", "env", "cwd")
 
-    def __init__(self, cmd, envvars):
+    def __init__(self, cmd, env=None, cwd=None):
         self.cmd = cmd
-        self.envvars = envvars
+        self.env = env or {}
+        self.cwd = cwd
 
     def __repr__(self):
-        return "BoundEnvCommand(%r, %r)" % (self.cmd, self.envvars)
+        return "BoundEnvCommand({!r}, {!r})".format(self.cmd, self.env)
 
     def _get_encoding(self):
         return self.cmd._get_encoding()
@@ -332,9 +341,14 @@ class BoundEnvCommand(BaseCommand):
     def machine(self):
         return self.cmd.machine
 
-    def popen(self, args=(), **kwargs):
-        with self.machine.env(**self.envvars):
-            return self.cmd.popen(args, **kwargs)
+    def popen(self, args=(), cwd=None, env=None, **kwargs):
+        env = env or {}
+        return self.cmd.popen(
+            args,
+            cwd=self.cwd if cwd is None else cwd,
+            env=dict(self.env, **env),
+            **kwargs
+        )
 
 
 class Pipeline(BaseCommand):
@@ -345,15 +359,17 @@ class Pipeline(BaseCommand):
         self.dstcmd = dstcmd
 
     def __repr__(self):
-        return "Pipeline(%r, %r)" % (self.srccmd, self.dstcmd)
+        return "Pipeline({!r}, {!r})".format(self.srccmd, self.dstcmd)
 
     def _get_encoding(self):
         return self.srccmd._get_encoding() or self.dstcmd._get_encoding()
 
     def formulate(self, level=0, args=()):
-        return self.srccmd.formulate(level + 1) + ["|"
-                                                   ] + self.dstcmd.formulate(
-                                                       level + 1, args)
+        return (
+            self.srccmd.formulate(level + 1)
+            + ["|"]
+            + self.dstcmd.formulate(level + 1, args)
+        )
 
     @property
     def machine(self):
@@ -372,7 +388,7 @@ class Pipeline(BaseCommand):
         srcproc.stdout.close()
         if srcproc.stderr is not None:
             dstproc.stderr = srcproc.stderr
-        if srcproc.stdin and src_kwargs.get('stdin') != PIPE:
+        if srcproc.stdin and src_kwargs.get("stdin") != PIPE:
             srcproc.stdin.close()
         dstproc.srcproc = srcproc
 
@@ -391,12 +407,12 @@ class Pipeline(BaseCommand):
         dstproc_verify = dstproc.verify
 
         def verify(proc, retcode, timeout, stdout, stderr):
-            #TODO: right now it's impossible to specify different expected
+            # TODO: right now it's impossible to specify different expected
             # return codes for different stages of the pipeline
             try:
                 or_retcode = [0] + list(retcode)
             except TypeError:
-                if (retcode is None):
+                if retcode is None:
                     or_retcode = None  # no-retcode-verification acts "greedily"
                 else:
                     or_retcode = [0, retcode]
@@ -423,11 +439,12 @@ class BaseRedirection(BaseCommand):
         return self.cmd._get_encoding()
 
     def __repr__(self):
-        return "%s(%r, %r)" % (self.__class__.__name__, self.cmd, self.file)
+        return "{}({!r}, {!r})".format(self.__class__.__name__, self.cmd, self.file)
 
     def formulate(self, level=0, args=()):
         return self.cmd.formulate(level + 1, args) + [
-            self.SYM, shquote(getattr(self.file, "name", self.file))
+            self.SYM,
+            shquote(getattr(self.file, "name", self.file)),
         ]
 
     @property
@@ -439,10 +456,10 @@ class BaseRedirection(BaseCommand):
         from plumbum.machines.remote import RemotePath
 
         if self.KWARG in kwargs and kwargs[self.KWARG] not in (PIPE, None):
-            raise RedirectionError("%s is already redirected" % (self.KWARG, ))
+            raise RedirectionError("{} is already redirected".format(self.KWARG))
         if isinstance(self.file, RemotePath):
             raise TypeError("Cannot redirect to/from remote paths")
-        if isinstance(self.file, six.string_types + (LocalPath, )):
+        if isinstance(self.file, six.string_types + (LocalPath,)):
             f = kwargs[self.KWARG] = open(str(self.file), self.MODE)
         else:
             kwargs[self.KWARG] = self.file
@@ -506,8 +523,9 @@ class StdinDataRedirection(BaseCommand):
 
     def formulate(self, level=0, args=()):
         return [
-            "echo %s" % (shquote(self.data), ), "|",
-            self.cmd.formulate(level + 1, args)
+            "echo {}".format(shquote(self.data)),
+            "|",
+            self.cmd.formulate(level + 1, args),
         ]
 
     @property
@@ -518,14 +536,13 @@ class StdinDataRedirection(BaseCommand):
         if "stdin" in kwargs and kwargs["stdin"] != PIPE:
             raise RedirectionError("stdin is already redirected")
         data = self.data
-        if isinstance(data,
-                      six.unicode_type) and self._get_encoding() is not None:
+        if isinstance(data, six.unicode_type) and self._get_encoding() is not None:
             data = data.encode(self._get_encoding())
         f = TemporaryFile()
         while data:
-            chunk = data[:self.CHUNK_SIZE]
+            chunk = data[: self.CHUNK_SIZE]
             f.write(chunk)
-            data = data[self.CHUNK_SIZE:]
+            data = data[self.CHUNK_SIZE :]
         f.seek(0)
         # try:
         return self.cmd.popen(args, stdin=f, **kwargs)
@@ -547,7 +564,7 @@ class ConcreteCommand(BaseCommand):
         return str(self.executable)
 
     def __repr__(self):
-        return "{0}({1})".format(type(self).__name__, self.executable)
+        return "{}({})".format(type(self).__name__, self.executable)
 
     def _get_encoding(self):
         return self.custom_encoding
@@ -564,11 +581,10 @@ class ConcreteCommand(BaseCommand):
                     argv.extend(a.formulate(level + 1))
             elif isinstance(a, (list, tuple)):
                 argv.extend(
-                    shquote(b) if level >= self.QUOTE_LEVEL else six.str(b)
-                    for b in a)
+                    shquote(b) if level >= self.QUOTE_LEVEL else six.str(b) for b in a
+                )
             else:
-                argv.append(
-                    shquote(a) if level >= self.QUOTE_LEVEL else six.str(a))
+                argv.append(shquote(a) if level >= self.QUOTE_LEVEL else six.str(a))
         # if self.custom_encoding:
         #    argv = [a.encode(self.custom_encoding) for a in argv if isinstance(a, six.string_types)]
         return argv
