@@ -1,23 +1,25 @@
-import time
+# -*- coding: utf-8 -*-
 import atexit
 import heapq
+import sys
+import time
 from threading import Thread
+
 from plumbum.lib import IS_WIN32, six
 
-try:
-    from queue import Queue, Empty as QueueEmpty
-except ImportError:
-    from Queue import Queue, Empty as QueueEmpty  # type: ignore
-
-try:
+if sys.version_info >= (3,):
     from io import StringIO
-except ImportError:
-    from cStringIO import StringIO  # type: ignore
+    from queue import Empty as QueueEmpty
+    from queue import Queue
+else:
+    from cStringIO import StringIO
+    from Queue import Empty as QueueEmpty
+    from Queue import Queue
 
 
-#===================================================================================================
+# ===================================================================================================
 # utility functions
-#===================================================================================================
+# ===================================================================================================
 def _check_process(proc, retcode, timeout, stdout, stderr):
     proc.verify(retcode, timeout, stdout, stderr)
     return proc.returncode, stdout, stderr
@@ -25,7 +27,7 @@ def _check_process(proc, retcode, timeout, stdout, stderr):
 
 def _iter_lines_posix(proc, decode, linesize, line_timeout=None):
     try:
-        from selectors import DefaultSelector, EVENT_READ
+        from selectors import EVENT_READ, DefaultSelector
     except ImportError:
         # Pre Python 3.4 implementation
         from select import select
@@ -34,10 +36,14 @@ def _iter_lines_posix(proc, decode, linesize, line_timeout=None):
             while True:
                 rlist, _, _ = select([proc.stdout, proc.stderr], [], [], line_timeout)
                 if not rlist and line_timeout:
-                    raise ProcessLineTimedOut("popen line timeout expired", getattr(proc, "argv", None), getattr(proc, "machine", None))
+                    raise ProcessLineTimedOut(
+                        "popen line timeout expired",
+                        getattr(proc, "argv", None),
+                        getattr(proc, "machine", None),
+                    )
                 for stream in rlist:
-                    yield (stream is proc.stderr), decode(
-                        stream.readline(linesize))
+                    yield (stream is proc.stderr), decode(stream.readline(linesize))
+
     else:
         # Python 3.4 implementation
         def selector():
@@ -47,7 +53,11 @@ def _iter_lines_posix(proc, decode, linesize, line_timeout=None):
             while True:
                 ready = sel.select(line_timeout)
                 if not ready and line_timeout:
-                    raise ProcessLineTimedOut("popen line timeout expired", getattr(proc, "argv", None), getattr(proc, "machine", None))
+                    raise ProcessLineTimedOut(
+                        "popen line timeout expired",
+                        getattr(proc, "argv", None),
+                        getattr(proc, "machine", None),
+                    )
                 for key, mask in ready:
                     yield key.data, decode(key.fileobj.readline(linesize))
 
@@ -62,9 +72,7 @@ def _iter_lines_posix(proc, decode, linesize, line_timeout=None):
 
 
 def _iter_lines_win32(proc, decode, linesize, line_timeout=None):
-
     class Piper(Thread):
-
         def __init__(self, fd, pipe):
             super().__init__(name="PlumbumPiper%sThread" % fd)
             self.pipe = pipe
@@ -77,7 +85,7 @@ def _iter_lines_win32(proc, decode, linesize, line_timeout=None):
             return self.pipe.readline(linesize)
 
         def run(self):
-            for line in iter(self.read_from_pipe, b''):
+            for line in iter(self.read_from_pipe, b""):
                 queue.put((self.fd, decode(line)))
             # self.pipe.close()
 
@@ -95,7 +103,11 @@ def _iter_lines_win32(proc, decode, linesize, line_timeout=None):
         except QueueEmpty:
             empty = True
         if time.time() - last_line_ts > line_timeout:
-            raise ProcessLineTimedOut("popen line timeout expired", getattr(proc, "argv", None), getattr(proc, "machine", None))
+            raise ProcessLineTimedOut(
+                "popen line timeout expired",
+                getattr(proc, "argv", None),
+                getattr(proc, "machine", None),
+            )
         if proc.poll() is not None:
             break
         if empty:
@@ -117,9 +129,9 @@ else:
     _iter_lines = _iter_lines_posix
 
 
-#===================================================================================================
+# ===================================================================================================
 # Exceptions
-#===================================================================================================
+# ===================================================================================================
 class ProcessExecutionError(EnvironmentError):
     """Represents the failure of a process. When the exit code of a terminated process does not
     match the expected result, this exception is raised by :func:`run_proc
@@ -127,8 +139,9 @@ class ProcessExecutionError(EnvironmentError):
     well as the command line used to create the process (``argv``)
     """
 
-    def __init__(self, argv, retcode, stdout, stderr):
+    def __init__(self, argv, retcode, stdout, stderr, message=None):
         Exception.__init__(self, argv, retcode, stdout, stderr)
+        self.message = message
         self.argv = argv
         self.retcode = retcode
         if six.PY3 and isinstance(stdout, six.bytes):
@@ -139,13 +152,19 @@ class ProcessExecutionError(EnvironmentError):
         self.stderr = stderr
 
     def __str__(self):
+        # avoid an import cycle
         from plumbum.commands.base import shquote_list
-        stdout =      "\n              | ".join(str(self.stdout).splitlines())
-        stderr =      "\n              | ".join(str(self.stderr).splitlines())
+
+        stdout = "\n              | ".join(str(self.stdout).splitlines())
+        stderr = "\n              | ".join(str(self.stderr).splitlines())
         cmd = " ".join(shquote_list(self.argv))
-        lines = ["Unexpected exit code: ", str(self.retcode)]
-        cmd =         "\n              | ".join(cmd.splitlines())
-        lines +=     ["\nCommand line: | ", cmd]
+        lines = []
+        if self.message:
+            lines = [self.message, "\nReturn code:  | ", str(self.retcode)]
+        else:
+            lines = ["Unexpected exit code: ", str(self.retcode)]
+        cmd = "\n              | ".join(cmd.splitlines())
+        lines += ["\nCommand line: | ", cmd]
         if stdout:
             lines += ["\nStdout:       | ", stdout]
         if stderr:
@@ -165,6 +184,7 @@ class ProcessTimedOut(Exception):
 class ProcessLineTimedOut(Exception):
     """Raises by :func:`iter_lines <plumbum.commands.iter_lines>` when a ``line_timeout`` has been
     specified and it has elapsed before the process yielded another line"""
+
     def __init__(self, msg, argv, machine):
         Exception.__init__(self, msg, argv, machine)
         self.argv = argv
@@ -182,9 +202,9 @@ class CommandNotFound(AttributeError):
         self.path = path
 
 
-#===================================================================================================
+# ===================================================================================================
 # Timeout thread
-#===================================================================================================
+# ===================================================================================================
 class MinHeap(object):
     def __init__(self, items=()):
         self._items = list(items)
@@ -245,7 +265,7 @@ def _timeout_thread_func():
 
 
 bgthd = Thread(target=_timeout_thread_func, name="PlumbumTimeoutThread")
-bgthd.setDaemon(True)
+bgthd.daemon = True
 bgthd.start()
 
 
@@ -267,9 +287,9 @@ def _shutdown_bg_threads():
 atexit.register(_shutdown_bg_threads)
 
 
-#===================================================================================================
+# ===================================================================================================
 # run_proc
-#===================================================================================================
+# ===================================================================================================
 def run_proc(proc, retcode, timeout=None):
     """Waits for the given process to terminate, with the expected exit code
 
@@ -302,23 +322,24 @@ def run_proc(proc, retcode, timeout=None):
     return _check_process(proc, retcode, timeout, stdout, stderr)
 
 
-#===================================================================================================
+# ===================================================================================================
 # iter_lines
-#===================================================================================================
+# ===================================================================================================
 
 BY_POSITION = object()
 BY_TYPE = object()
 DEFAULT_ITER_LINES_MODE = BY_POSITION
 
 
-def iter_lines(proc,
-               retcode=0,
-               timeout=None,
-               linesize=-1,
-               line_timeout=None,
-               mode=None,
-               _iter_lines=_iter_lines,
-               ):
+def iter_lines(
+    proc,
+    retcode=0,
+    timeout=None,
+    linesize=-1,
+    line_timeout=None,
+    mode=None,
+    _iter_lines=_iter_lines,
+):
     """Runs the given process (equivalent to run_proc()) and yields a tuples of (out, err) line pairs.
     If the exit code of the process does not match the expected one, :class:`ProcessExecutionError
     <plumbum.commands.ProcessExecutionError>` is raised.
@@ -346,11 +367,8 @@ def iter_lines(proc,
 
     assert mode in (BY_POSITION, BY_TYPE)
 
-    encoding = getattr(proc, "custom_encoding", None)
-    if encoding:
-        decode = lambda s: s.decode(encoding).rstrip()
-    else:
-        decode = lambda s: s
+    encoding = getattr(proc, "custom_encoding", None) or "utf-8"
+    decode = lambda s: s.decode(encoding, errors="replace").rstrip()
 
     _register_proc_timeout(proc, timeout)
 
