@@ -1,10 +1,11 @@
-import sys
-import os
-from contextlib import contextmanager
-from abc import ABCMeta
+# -*- coding: utf-8 -*-
 import inspect
+import os
+import re
+import sys
+from contextlib import contextmanager
 
-IS_WIN32 = (sys.platform == "win32")
+IS_WIN32 = sys.platform == "win32"
 
 
 def _setdoc(super):  # @ReservedAssignment
@@ -12,8 +13,7 @@ def _setdoc(super):  # @ReservedAssignment
     due to new behavoir of inspect.getdoc, but still doesn't hurt."""
 
     def deco(func):
-        func.__doc__ = getattr(
-            getattr(super, func.__name__, None), "__doc__", None)
+        func.__doc__ = getattr(getattr(super, func.__name__, None), "__doc__", None)
         return func
 
     return deco
@@ -27,34 +27,35 @@ class ProcInfo(object):
         self.args = args
 
     def __repr__(self):
-        return "ProcInfo(%r, %r, %r, %r)" % (self.pid, self.uid, self.stat,
-                                             self.args)
+        return "ProcInfo({!r}, {!r}, {!r}, {!r})".format(
+            self.pid, self.uid, self.stat, self.args
+        )
 
 
 class six(object):
     """
     A light-weight version of six (which works on IronPython)
     """
+
     PY3 = sys.version_info[0] >= 3
-    try:
+    if sys.version_info >= (3, 4):
         from abc import ABC
-    except ImportError:
-        from abc import ABCMeta  # type: ignore
-        ABC = ABCMeta('ABC', (object, ), {
-            '__module__': __name__,
-            '__slots__': ()
-        })  # type: ignore
+    else:
+        from abc import ABCMeta
+
+        ABC = ABCMeta("ABC", (object,), {"__module__": __name__, "__slots__": ()})
 
     # Be sure to use named-tuple access, so that usage is not affected
     try:
         getfullargspec = staticmethod(inspect.getfullargspec)
     except AttributeError:
         getfullargspec = staticmethod(
-            inspect.getargspec)  # extra fields will not be available
+            inspect.getargspec
+        )  # extra fields will not be available
 
     if PY3:
-        integer_types = (int, )
-        string_types = (str, )
+        integer_types = (int,)
+        string_types = (str,)
         MAXSIZE = sys.maxsize
         ascii = ascii  # @UndefinedVariable
         bytes = bytes  # @ReservedAssignment
@@ -71,6 +72,7 @@ class six(object):
         @staticmethod
         def get_method_function(m):
             return m.__func__
+
     else:
         integer_types = (int, long)
         string_types = (str, unicode)
@@ -96,10 +98,24 @@ class six(object):
 
 # Try/except fails because io has the wrong StringIO in Python2
 # You'll get str/unicode errors
-if six.PY3:
+if sys.version_info >= (3, 0):
     from io import StringIO
 else:
-    from StringIO import StringIO  # type: ignore
+    from StringIO import StringIO
+
+if sys.version_info >= (3,):
+    from glob import escape as glob_escape
+else:
+    _magic_check = re.compile(u"([*?[])")
+    _magic_check_bytes = re.compile(b"([*?[])")
+
+    def glob_escape(pathname):
+        drive, pathname = os.path.splitdrive(pathname)
+        if isinstance(pathname, str):
+            pathname = _magic_check_bytes.sub(r"[\1]", pathname)
+        else:
+            pathname = _magic_check.sub(u"[\\1]", pathname)
+        return drive + pathname
 
 
 @contextmanager
@@ -156,7 +172,7 @@ def read_fd_decode_safely(fd, size=4096):
         try:
             return data, data.decode("utf-8")
         except UnicodeDecodeError as e:
-            if e.reason != 'unexpected end of data':
+            if e.reason != "unexpected end of data":
                 raise
             if i == 3:
                 raise
