@@ -1,24 +1,25 @@
-import logging
+# -*- coding: utf-8 -*-
 import errno
+import logging
 import os
-import stat
 import socket
+import stat
+
 from plumbum.commands.base import shquote
+from plumbum.commands.processes import ProcessLineTimedOut, iter_lines
+from plumbum.lib import _setdoc, six
 from plumbum.machines.base import PopenAddons
 from plumbum.machines.remote import BaseRemoteMachine
 from plumbum.machines.session import ShellSession
-from plumbum.lib import _setdoc, six
 from plumbum.path.local import LocalPath
 from plumbum.path.remote import RemotePath, StatRes
-from plumbum.commands.processes import iter_lines, ProcessLineTimedOut
-
 
 try:
     # Sigh... we need to gracefully-import paramiko for Sphinx builds, etc
     import paramiko
 except ImportError:
 
-    class paramiko(object):
+    class paramiko(object):  # type: ignore
         def __nonzero__(self):
             return False
 
@@ -27,21 +28,23 @@ except ImportError:
         def __getattr__(self, name):
             raise ImportError("No module named paramiko")
 
-    paramiko = paramiko()
+    paramiko = paramiko()  # type: ignore
 
 logger = logging.getLogger("plumbum.paramiko")
 
 
 class ParamikoPopen(PopenAddons):
-    def __init__(self,
-                 argv,
-                 stdin,
-                 stdout,
-                 stderr,
-                 encoding,
-                 stdin_file=None,
-                 stdout_file=None,
-                 stderr_file=None):
+    def __init__(
+        self,
+        argv,
+        stdin,
+        stdout,
+        stderr,
+        encoding,
+        stdin_file=None,
+        stdout_file=None,
+        stderr_file=None,
+    ):
         self.argv = argv
         self.channel = stdout.channel
         self.stdin = stdin
@@ -76,8 +79,7 @@ class ParamikoPopen(PopenAddons):
         # possible way to obtain pid:
         # "(cmd ; echo $?) & echo ?!"
         # and then client.exec_command("kill -9 %s" % (pid,))
-        raise EnvironmentError(
-            "Cannot kill remote processes, we don't have their PIDs")
+        raise EnvironmentError("Cannot kill remote processes, we don't have their PIDs")
 
     terminate = kill
 
@@ -88,8 +90,10 @@ class ParamikoPopen(PopenAddons):
         stdout = []
         stderr = []
         infile = self.stdin_file
-        sources = [("1", stdout, self.stdout, self.stdout_file),
-                   ("2", stderr, self.stderr, self.stderr_file)]
+        sources = [
+            ("1", stdout, self.stdout, self.stdout_file),
+            ("2", stderr, self.stderr, self.stderr_file),
+        ]
         i = 0
         while sources:
             if infile:
@@ -205,29 +209,31 @@ class ParamikoMachine(BaseRemoteMachine):
         def __lshift__(self, *_):
             raise NotImplementedError("Not supported with ParamikoMachine")
 
-    def __init__(self,
-                 host,
-                 user=None,
-                 port=None,
-                 password=None,
-                 keyfile=None,
-                 load_system_host_keys=True,
-                 missing_host_policy=None,
-                 encoding="utf8",
-                 look_for_keys=None,
-                 connect_timeout=None,
-                 keep_alive=0,
-                 gss_auth=False,
-                 gss_kex=None,
-                 gss_deleg_creds=None,
-                 gss_host=None,
-                 get_pty=False,
-                 load_system_ssh_config=False):
+    def __init__(
+        self,
+        host,
+        user=None,
+        port=None,
+        password=None,
+        keyfile=None,
+        load_system_host_keys=True,
+        missing_host_policy=None,
+        encoding="utf8",
+        look_for_keys=None,
+        connect_timeout=None,
+        keep_alive=0,
+        gss_auth=False,
+        gss_kex=None,
+        gss_deleg_creds=None,
+        gss_host=None,
+        get_pty=False,
+        load_system_ssh_config=False,
+    ):
         self.host = host
         kwargs = {}
         if user:
-            self._fqhost = "%s@%s" % (user, host)
-            kwargs['username'] = user
+            self._fqhost = "{}@{}".format(user, host)
+            kwargs["username"] = user
         else:
             self._fqhost = host
         self._client = paramiko.SSHClient()
@@ -246,19 +252,19 @@ class ParamikoMachine(BaseRemoteMachine):
         if connect_timeout is not None:
             kwargs["timeout"] = connect_timeout
         if gss_auth:
-            kwargs['gss_auth'] = gss_auth
-            kwargs['gss_kex'] = gss_kex
-            kwargs['gss_deleg_creds'] = gss_deleg_creds
+            kwargs["gss_auth"] = gss_auth
+            kwargs["gss_kex"] = gss_kex
+            kwargs["gss_deleg_creds"] = gss_deleg_creds
             if not gss_host:
                 gss_host = host
-            kwargs['gss_host'] = gss_host
+            kwargs["gss_host"] = gss_host
         if load_system_ssh_config:
             ssh_config = paramiko.SSHConfig()
-            with open(os.path.expanduser('~/.ssh/config')) as f:
+            with open(os.path.expanduser("~/.ssh/config")) as f:
                 ssh_config.parse(f)
             try:
                 hostConfig = ssh_config.lookup(host)
-                kwargs['sock'] = paramiko.ProxyCommand(hostConfig['proxycommand'])
+                kwargs["sock"] = paramiko.ProxyCommand(hostConfig["proxycommand"])
             except KeyError:
                 pass
         self._client.connect(host, **kwargs)
@@ -268,7 +274,7 @@ class ParamikoMachine(BaseRemoteMachine):
         BaseRemoteMachine.__init__(self, encoding, connect_timeout)
 
     def __str__(self):
-        return "paramiko://%s" % (self._fqhost, )
+        return "paramiko://{}".format(self._fqhost)
 
     def close(self):
         BaseRemoteMachine.close(self)
@@ -285,12 +291,9 @@ class ParamikoMachine(BaseRemoteMachine):
         return self._sftp
 
     @_setdoc(BaseRemoteMachine)
-    def session(self,
-                isatty=False,
-                term="vt100",
-                width=80,
-                height=24,
-                new_session=False):
+    def session(
+        self, isatty=False, term="vt100", width=80, height=24, new_session=False
+    ):
         # new_session is ignored for ParamikoMachine
         trans = self._client.get_transport()
         trans.set_keepalive(self._keep_alive)
@@ -299,28 +302,32 @@ class ParamikoMachine(BaseRemoteMachine):
             chan.get_pty(term, width, height)
             chan.set_combine_stderr(True)
         chan.invoke_shell()
-        stdin = chan.makefile('wb', -1)
-        stdout = chan.makefile('rb', -1)
-        stderr = chan.makefile_stderr('rb', -1)
-        proc = ParamikoPopen(["<shell>"], stdin, stdout, stderr,
-                             self.custom_encoding)
+        stdin = chan.makefile("wb", -1)
+        stdout = chan.makefile("rb", -1)
+        stderr = chan.makefile_stderr("rb", -1)
+        proc = ParamikoPopen(["<shell>"], stdin, stdout, stderr, self.custom_encoding)
         return ShellSession(proc, self.custom_encoding, isatty)
 
     @_setdoc(BaseRemoteMachine)
-    def popen(self,
-              args,
-              stdin=None,
-              stdout=None,
-              stderr=None,
-              new_session=False,
-              cwd=None):
+    def popen(
+        self,
+        args,
+        stdin=None,
+        stdout=None,
+        stderr=None,
+        new_session=False,
+        env=None,
+        cwd=None,
+    ):
         # new_session is ignored for ParamikoMachine
         argv = []
         envdelta = self.env.getdelta()
+        if env:
+            envdelta.update(env)
         argv.extend(["cd", str(cwd or self.cwd), "&&"])
         if envdelta:
             argv.append("env")
-            argv.extend("%s=%s" % (k, shquote(v)) for k, v in envdelta.items())
+            argv.extend("{}={}".format(k, shquote(v)) for k, v in envdelta.items())
         argv.extend(args.formulate())
         cmdline = " ".join(argv)
         logger.debug(cmdline)
@@ -333,20 +340,21 @@ class ParamikoMachine(BaseRemoteMachine):
             self.custom_encoding,
             stdin_file=stdin,
             stdout_file=stdout,
-            stderr_file=stderr)
+            stderr_file=stderr,
+        )
 
     @_setdoc(BaseRemoteMachine)
     def download(self, src, dst):
         if isinstance(src, LocalPath):
-            raise TypeError("src of download cannot be %r" % (src, ))
+            raise TypeError("src of download cannot be {!r}".format(src))
         if isinstance(src, RemotePath) and src.remote != self:
-            raise TypeError(
-                "src %r points to a different remote machine" % (src, ))
+            raise TypeError("src {!r} points to a different remote machine".format(src))
         if isinstance(dst, RemotePath):
-            raise TypeError("dst of download cannot be %r" % (dst, ))
+            raise TypeError("dst of download cannot be {!r}".format(dst))
         return self._download(
-            src if isinstance(src, RemotePath) else self.path(src), dst
-            if isinstance(dst, LocalPath) else LocalPath(dst))
+            src if isinstance(src, RemotePath) else self.path(src),
+            dst if isinstance(dst, LocalPath) else LocalPath(dst),
+        )
 
     def _download(self, src, dst):
         if src.is_dir():
@@ -362,15 +370,15 @@ class ParamikoMachine(BaseRemoteMachine):
     @_setdoc(BaseRemoteMachine)
     def upload(self, src, dst):
         if isinstance(src, RemotePath):
-            raise TypeError("src of upload cannot be %r" % (src, ))
+            raise TypeError("src of upload cannot be {!r}".format(src))
         if isinstance(dst, LocalPath):
-            raise TypeError("dst of upload cannot be %r" % (dst, ))
+            raise TypeError("dst of upload cannot be {!r}".format(dst))
         if isinstance(dst, RemotePath) and dst.remote != self:
-            raise TypeError(
-                "dst %r points to a different remote machine" % (dst, ))
+            raise TypeError("dst {!r} points to a different remote machine".format(dst))
         return self._upload(
-            src if isinstance(src, LocalPath) else LocalPath(src), dst
-            if isinstance(dst, RemotePath) else self.path(dst))
+            src if isinstance(src, LocalPath) else LocalPath(src),
+            dst if isinstance(dst, RemotePath) else self.path(dst),
+        )
 
     def _upload(self, src, dst):
         if src.is_dir():
@@ -399,7 +407,7 @@ class ParamikoMachine(BaseRemoteMachine):
         srcaddr = ("::1", 0, 0, 0) if ipv6 else ("127.0.0.1", 0)
         trans = self._client.get_transport()
         trans.set_keepalive(self._keep_alive)
-        chan = trans.open_channel('direct-tcpip', (dhost, dport), srcaddr)
+        chan = trans.open_channel("direct-tcpip", (dhost, dport), srcaddr)
         return SocketCompatibleChannel(chan)
 
     #
@@ -409,7 +417,7 @@ class ParamikoMachine(BaseRemoteMachine):
         return self.sftp.listdir(str(fn))
 
     def _path_read(self, fn):
-        f = self.sftp.open(str(fn), 'rb')
+        f = self.sftp.open(str(fn), "rb")
         data = f.read()
         f.close()
         return data
@@ -417,7 +425,7 @@ class ParamikoMachine(BaseRemoteMachine):
     def _path_write(self, fn, data):
         if self.custom_encoding and isinstance(data, six.unicode_type):
             data = data.encode(self.custom_encoding)
-        f = self.sftp.open(str(fn), 'wb')
+        f = self.sftp.open(str(fn), "wb")
         f.write(data)
         f.close()
 
@@ -428,13 +436,25 @@ class ParamikoMachine(BaseRemoteMachine):
             if e.errno == errno.ENOENT:
                 return None
             raise OSError(e.errno)
-        res = StatRes((st.st_mode, 0, 0, 0, st.st_uid, st.st_gid, st.st_size,
-                       st.st_atime, st.st_mtime, 0))
+        res = StatRes(
+            (
+                st.st_mode,
+                0,
+                0,
+                0,
+                st.st_uid,
+                st.st_gid,
+                st.st_size,
+                st.st_atime,
+                st.st_mtime,
+                0,
+            )
+        )
 
         if stat.S_ISDIR(st.st_mode):
-            res.text_mode = 'directory'
+            res.text_mode = "directory"
         if stat.S_ISREG(st.st_mode):
-            res.text_mode = 'regular file'
+            res.text_mode = "regular file"
         return res
 
 
@@ -451,12 +471,12 @@ class SocketCompatibleChannel(object):
 
     def send(self, s):
         if self._chan.closed:
-            raise socket.error(errno.EBADF, 'Bad file descriptor')
+            raise socket.error(errno.EBADF, "Bad file descriptor")
         return self._chan.send(s)
 
     def recv(self, count):
         if self._chan.closed:
-            raise socket.error(errno.EBADF, 'Bad file descriptor')
+            raise socket.error(errno.EBADF, "Bad file descriptor")
         return self._chan.recv(count)
 
 
@@ -466,7 +486,7 @@ class SocketCompatibleChannel(object):
 def _iter_lines(proc, decode, linesize, line_timeout=None):
 
     try:
-        from selectors import DefaultSelector, EVENT_READ
+        from selectors import EVENT_READ, DefaultSelector
     except ImportError:
         # Pre Python 3.4 implementation
         from select import select
@@ -475,9 +495,14 @@ def _iter_lines(proc, decode, linesize, line_timeout=None):
             while True:
                 rlist, _, _ = select([proc.stdout.channel], [], [], line_timeout)
                 if not rlist and line_timeout:
-                    raise ProcessLineTimedOut("popen line timeout expired", getattr(proc, "argv", None), getattr(proc, "machine", None))
+                    raise ProcessLineTimedOut(
+                        "popen line timeout expired",
+                        getattr(proc, "argv", None),
+                        getattr(proc, "machine", None),
+                    )
                 for _ in rlist:
                     yield
+
     else:
         # Python 3.4 implementation
         def selector():
@@ -486,7 +511,11 @@ def _iter_lines(proc, decode, linesize, line_timeout=None):
             while True:
                 ready = sel.select(line_timeout)
                 if not ready and line_timeout:
-                    raise ProcessLineTimedOut("popen line timeout expired", getattr(proc, "argv", None), getattr(proc, "machine", None))
+                    raise ProcessLineTimedOut(
+                        "popen line timeout expired",
+                        getattr(proc, "argv", None),
+                        getattr(proc, "machine", None),
+                    )
                 for key, mask in ready:
                     yield
 
