@@ -1,23 +1,26 @@
-import os
-import sys
-import glob
-import shutil
+# -*- coding: utf-8 -*-
 import errno
+import glob
 import logging
+import os
+import shutil
+import sys
 from contextlib import contextmanager
-from plumbum.lib import _setdoc, IS_WIN32, six
-from plumbum.path.base import Path, FSUser
+
+from plumbum.lib import IS_WIN32, _setdoc, glob_escape, six
+from plumbum.path.base import FSUser, Path
 from plumbum.path.remote import RemotePath
+
 try:
-    from pwd import getpwuid, getpwnam
     from grp import getgrgid, getgrnam
+    from pwd import getpwnam, getpwuid
 except ImportError:
 
     def getpwuid(x):  # type: ignore
-        return (None, )
+        return (None,)
 
     def getgrgid(x):  # type: ignore
-        return (None, )
+        return (None,)
 
     def getpwnam(x):  # type: ignore
         raise OSError("`getpwnam` not supported")
@@ -30,37 +33,37 @@ try:  # Py3
     import urllib.parse as urlparse
     import urllib.request as urllib
 except ImportError:
-    import urlparse  # type: ignore
     import urllib  # type: ignore
 
+    import urlparse  # type: ignore
+
 logger = logging.getLogger("plumbum.local")
 
 
-#===================================================================================================
+# ===================================================================================================
 # Local Paths
-#===================================================================================================
+# ===================================================================================================
 class LocalPath(Path):
     """The class implementing local-machine paths"""
 
     CASE_SENSITIVE = not IS_WIN32
 
     def __new__(cls, *parts):
-        if len(parts) == 1 and \
-                isinstance(parts[0], cls) and \
-                not isinstance(parts[0], LocalWorkdir):
+        if (
+            len(parts) == 1
+            and isinstance(parts[0], cls)
+            and not isinstance(parts[0], LocalWorkdir)
+        ):
             return parts[0]
         if not parts:
             raise TypeError("At least one path part is required (none given)")
         if any(isinstance(path, RemotePath) for path in parts):
-            raise TypeError(
-                "LocalPath cannot be constructed from %r" % (parts, ))
+            raise TypeError("LocalPath cannot be constructed from {!r}".format(parts))
         self = super(LocalPath, cls).__new__(
-            cls, os.path.normpath(os.path.join(*(str(p) for p in parts))))
+            cls, os.path.normpath(os.path.join(*(str(p) for p in parts)))
+        )
         return self
 
-    def __fspath__(self):
-        return self._path()
-
     @property
     def _path(self):
         return str(self)
@@ -157,19 +160,19 @@ class LocalPath(Path):
 
     @_setdoc(Path)
     def with_suffix(self, suffix, depth=1):
-        if (suffix and not suffix.startswith(os.path.extsep)
-                or suffix == os.path.extsep):
+        if suffix and not suffix.startswith(os.path.extsep) or suffix == os.path.extsep:
             raise ValueError("Invalid suffix %r" % (suffix))
         name = self.name
-        depth = len(self.suffixes) if depth is None else min(
-            depth, len(self.suffixes))
-        for i in range(depth):
-            name, ext = os.path.splitext(name)
+        depth = len(self.suffixes) if depth is None else min(depth, len(self.suffixes))
+        for _ in range(depth):
+            name, _ = os.path.splitext(name)
         return LocalPath(self.dirname) / (name + suffix)
 
     @_setdoc(Path)
     def glob(self, pattern):
-        fn = lambda pat: [LocalPath(m) for m in glob.glob(str(self / pat))]
+        fn = lambda pat: [
+            LocalPath(m) for m in glob.glob(os.path.join(glob_escape(str(self)), pat))
+        ]
         return self._glob(pattern, fn)
 
     @_setdoc(Path)
@@ -190,14 +193,14 @@ class LocalPath(Path):
     @_setdoc(Path)
     def move(self, dst):
         if isinstance(dst, RemotePath):
-            raise TypeError("Cannot move local path %s to %r" % (self, dst))
+            raise TypeError("Cannot move local path {} to {!r}".format(self, dst))
         shutil.move(str(self), str(dst))
         return LocalPath(dst)
 
     @_setdoc(Path)
     def copy(self, dst, override=None):
         if isinstance(dst, RemotePath):
-            raise TypeError("Cannot copy local path %s to %r" % (self, dst))
+            raise TypeError("Cannot copy local path {} to {!r}".format(self, dst))
         dst = LocalPath(dst)
         if override is False and dst.exists():
             raise TypeError("File exists and override was not specified")
@@ -231,9 +234,9 @@ class LocalPath(Path):
         return open(str(self), mode)
 
     @_setdoc(Path)
-    def read(self, encoding=None, mode='r'):
-        if encoding and 'b' not in mode:
-            mode = mode + 'b'
+    def read(self, encoding=None, mode="r"):
+        if encoding and "b" not in mode:
+            mode = mode + "b"
         with self.open(mode) as f:
             data = f.read()
             if encoding:
@@ -246,25 +249,31 @@ class LocalPath(Path):
             data = data.encode(encoding)
         if mode is None:
             if isinstance(data, six.unicode_type):
-                mode = 'w'
+                mode = "w"
             else:
-                mode = 'wb'
+                mode = "wb"
         with self.open(mode) as f:
             f.write(data)
 
     @_setdoc(Path)
     def touch(self):
-        with open(str(self), 'a'):
+        with open(str(self), "a"):
             os.utime(str(self), None)
 
     @_setdoc(Path)
     def chown(self, owner=None, group=None, recursive=None):
         if not hasattr(os, "chown"):
             raise OSError("os.chown() not supported")
-        uid = self.uid if owner is None else (owner if isinstance(owner, int)
-                                              else getpwnam(owner)[2])
-        gid = self.gid if group is None else (group if isinstance(group, int)
-                                              else getgrnam(group)[2])
+        uid = (
+            self.uid
+            if owner is None
+            else (owner if isinstance(owner, int) else getpwnam(owner)[2])
+        )
+        gid = (
+            self.gid
+            if group is None
+            else (group if isinstance(group, int) else getgrnam(group)[2])
+        )
         os.chown(str(self), uid, gid)
         if recursive or (recursive is None and self.is_dir()):
             for subpath in self.walk():
@@ -283,12 +292,14 @@ class LocalPath(Path):
     @_setdoc(Path)
     def link(self, dst):
         if isinstance(dst, RemotePath):
-            raise TypeError("Cannot create a hardlink from local path %s to %r"
-                            % (self, dst))
+            raise TypeError(
+                "Cannot create a hardlink from local path {} to {!r}".format(self, dst)
+            )
         if hasattr(os, "link"):
             os.link(str(self), str(dst))
         else:
             from plumbum.machines.local import local
+
             # windows: use mklink
             if self.is_dir():
                 local["cmd"]("/C", "mklink", "/D", "/H", str(dst), str(self))
@@ -298,12 +309,14 @@ class LocalPath(Path):
     @_setdoc(Path)
     def symlink(self, dst):
         if isinstance(dst, RemotePath):
-            raise TypeError("Cannot create a symlink from local path %s to %r"
-                            % (self, dst))
+            raise TypeError(
+                "Cannot create a symlink from local path {} to {!r}".format(self, dst)
+            )
         if hasattr(os, "symlink"):
             os.symlink(str(self), str(dst))
         else:
             from plumbum.machines.local import local
+
             # windows: use mklink
             if self.is_dir():
                 local["cmd"]("/C", "mklink", "/D", str(dst), str(self))
@@ -325,9 +338,8 @@ class LocalPath(Path):
                 raise
 
     @_setdoc(Path)
-    def as_uri(self, scheme='file'):
-        return urlparse.urljoin(
-            str(scheme) + ':', urllib.pathname2url(str(self)))
+    def as_uri(self, scheme="file"):
+        return urlparse.urljoin(str(scheme) + ":", urllib.pathname2url(str(self)))
 
     @property  # type: ignore
     @_setdoc(Path)
@@ -355,7 +367,7 @@ class LocalWorkdir(LocalPath):
         :param newdir: The destination director (a string or a ``LocalPath``)
         """
         if isinstance(newdir, RemotePath):
-            raise TypeError("newdir cannot be %r" % (newdir, ))
+            raise TypeError("newdir cannot be {!r}".format(newdir))
         logger.debug("Chdir to %s", newdir)
         os.chdir(str(newdir))
         return self.__class__()
