@@ -1,8 +1,10 @@
-from plumbum.path.base import Path
-from plumbum.lib import six
-from plumbum.machines.local import local, LocalPath
+# -*- coding: utf-8 -*-
 import os
 
+from plumbum.lib import six
+from plumbum.machines.local import LocalPath, local
+from plumbum.path.base import Path
+
 
 def delete(*paths):
     """Deletes the given paths. The arguments can be either strings,
@@ -18,7 +20,7 @@ def delete(*paths):
         elif hasattr(p, "__iter__"):
             delete(*p)
         else:
-            raise TypeError("Cannot delete %r" % (p, ))
+            raise TypeError("Cannot delete {!r}".format(p))
 
 
 def _move(src, dst):
@@ -43,8 +45,8 @@ def move(src, dst):
             dst.mkdir()
         elif not dst.is_dir():
             raise ValueError(
-                "When using multiple sources, dst %r must be a directory" %
-                (dst, ))
+                "When using multiple sources, dst {!r} must be a directory".format(dst)
+            )
         for src2 in src:
             move(src2, dst)
         return dst
@@ -81,8 +83,8 @@ def copy(src, dst):
             dst.mkdir()
         elif not dst.is_dir():
             raise ValueError(
-                "When using multiple sources, dst %r must be a directory" %
-                (dst, ))
+                "When using multiple sources, dst {!r} must be a directory".format(dst)
+            )
         for src2 in src:
             copy(src2, dst)
         return dst
@@ -109,8 +111,8 @@ def copy(src, dst):
 
 def gui_open(filename):
     """This selects the proper gui open function. This can
-       also be achieved with webbrowser, but that is not supported."""
-    if (hasattr(os, "startfile")):
+    also be achieved with webbrowser, but that is not supported."""
+    if hasattr(os, "startfile"):
         os.startfile(filename)
     else:
-        local.get('xdg-open', 'open')(filename)
+        local.get("xdg-open", "open")(filename)
